You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@turbine.apache.org by tv...@apache.org on 2008/11/15 22:42:23 UTC

svn commit: r717932 - /turbine/core/trunk/src/java/org/apache/turbine/services/intake/IntakeTool.java

Author: tv
Date: Sat Nov 15 13:42:23 2008
New Revision: 717932

URL: http://svn.apache.org/viewvc?rev=717932&view=rev
Log:
Fixed some warnings concerning synthetic accessors

Modified:
    turbine/core/trunk/src/java/org/apache/turbine/services/intake/IntakeTool.java

Modified: turbine/core/trunk/src/java/org/apache/turbine/services/intake/IntakeTool.java
URL: http://svn.apache.org/viewvc/turbine/core/trunk/src/java/org/apache/turbine/services/intake/IntakeTool.java?rev=717932&r1=717931&r2=717932&view=diff
==============================================================================
--- turbine/core/trunk/src/java/org/apache/turbine/services/intake/IntakeTool.java (original)
+++ turbine/core/trunk/src/java/org/apache/turbine/services/intake/IntakeTool.java Sat Nov 15 13:42:23 2008
@@ -53,7 +53,7 @@
         implements ApplicationTool, Recyclable
 {
     /** Used for logging */
-    private static Log log = LogFactory.getLog(IntakeTool.class);
+    protected static Log log = LogFactory.getLog(IntakeTool.class);
 
     /** Constant for default key */
     public static final String DEFAULT_KEY = "_0";
@@ -62,14 +62,14 @@
     public static final String INTAKE_GRP = "intake-grp";
 
     /** Groups from intake.xml */
-    private HashMap groups;
+    protected HashMap groups;
 
     /** ValueParser instance */
-    private ValueParser pp;
+    protected ValueParser pp;
 
-    HashMap declaredGroups = new HashMap();
-    StringBuffer allGroupsSB = new StringBuffer(256);
-    StringBuffer groupSB = new StringBuffer(128);
+    private HashMap declaredGroups = new HashMap();
+    private StringBuffer allGroupsSB = new StringBuffer(256);
+    private StringBuffer groupSB = new StringBuffer(128);
 
     /** The cache of PullHelpers. **/
     private Map pullMap;
@@ -231,11 +231,11 @@
         String groupName;
 
         /**
          * Private constructor to force use of factory method.
          *
          * @param groupName
          */
-        private PullHelper(String groupName)
+        protected PullHelper(String groupName)
         {
             this.groupName = groupName;
         }
@@ -231,11 +231,11 @@
 
         /**
-         * Private constructor to force use of factory method.
+         * Protected constructor to force use of factory method.
          *
          * @param groupName